==> kubernetes-model-gatewayapi-6.4.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TLSRouteFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSRouteFluent<A extends TLSRouteFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public TLSRouteFluent.MetadataNested<A> withNewMetadata();
  public TLSRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public TLSRouteFluent.MetadataNested<A> editMetadata();
  public TLSRouteFluent.MetadataNested<A> editOrNewMetadata();
  public TLSRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TLSRouteSpec getSpec();
  public TLSRouteSpec buildSpec();
  public A withSpec(TLSRouteSpec spec);
  public Boolean hasSpec();
  public TLSRouteFluent.SpecNested<A> withNewSpec();
  public TLSRouteFluent.SpecNested<A> withNewSpecLike(TLSRouteSpec item);
  public TLSRouteFluent.SpecNested<A> editSpec();
  public TLSRouteFluent.SpecNested<A> editOrNewSpec();
  public TLSRouteFluent.SpecNested<A> editOrNewSpecLike(TLSRouteSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public TLSRouteStatus getStatus();
  public TLSRouteStatus buildStatus();
  public A withStatus(TLSRouteStatus status);
  public Boolean hasStatus();
  public TLSRouteFluent.StatusNested<A> withNewStatus();
  public TLSRouteFluent.StatusNested<A> withNewStatusLike(TLSRouteStatus item);
  public TLSRouteFluent.StatusNested<A> editStatus();
  public TLSRouteFluent.StatusNested<A> editOrNewStatus();
  public TLSRouteFluent.StatusNested<A> editOrNewStatusLike(TLSRouteStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<TLSRouteFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,TLSRouteSpecFluent<TLSRouteFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,TLSRouteStatusFluent<TLSRouteFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TLSRouteFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSRouteFluent<A extends TLSRouteFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public TLSRouteFluent.MetadataNested<A> withNewMetadata();
  public TLSRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public TLSRouteFluent.MetadataNested<A> editMetadata();
  public TLSRouteFluent.MetadataNested<A> editOrNewMetadata();
  public TLSRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TLSRouteSpec getSpec();
  public TLSRouteSpec buildSpec();
  public A withSpec(TLSRouteSpec spec);
  public Boolean hasSpec();
  public TLSRouteFluent.SpecNested<A> withNewSpec();
  public TLSRouteFluent.SpecNested<A> withNewSpecLike(TLSRouteSpec item);
  public TLSRouteFluent.SpecNested<A> editSpec();
  public TLSRouteFluent.SpecNested<A> editOrNewSpec();
  public TLSRouteFluent.SpecNested<A> editOrNewSpecLike(TLSRouteSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public TLSRouteStatus getStatus();
  public TLSRouteStatus buildStatus();
  public A withStatus(TLSRouteStatus status);
  public Boolean hasStatus();
  public TLSRouteFluent.StatusNested<A> withNewStatus();
  public TLSRouteFluent.StatusNested<A> withNewStatusLike(TLSRouteStatus item);
  public TLSRouteFluent.StatusNested<A> editStatus();
  public TLSRouteFluent.StatusNested<A> editOrNewStatus();
  public TLSRouteFluent.StatusNested<A> editOrNewStatusLike(TLSRouteStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<TLSRouteFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,TLSRouteSpecFluent<TLSRouteFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,TLSRouteStatusFluent<TLSRouteFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
